@@ -4,7 +4,6 @@ $GF(3^m)$ is an extension field of $GF(3)$, and the degree of the extension is $
 In this module, an element of $GF(3^m)$ is a list of length $m$, where each element is in $GF(3)$. 
 """
 
-from . import it
 import random as _r
 
 'how many GF(3) elements are in one native machine integer.'
@@ -12,6 +11,8 @@ _W = 63
 # TODO: determine $_W$ by Python native integer length
 'degree of the irreducible polynomial'
 _m = None
+'irreducible polynomial is $x^m + x^t + 2$'
+_t = None
 '''the number of native machine integers required to represent one GF(3^m) element,
 assuming the machine word size is no less than 32.'''
 _ln = None
@@ -30,22 +31,59 @@ def _E(a = None):
                 _set(c2, i)
     return c
 
-def set_degree(m):
-    'choose another irreducible polynomial whose degree is $m$'
-    global _m, _ln, _p
+def _E2(a):
+    'only for unittest'
+    l = len(a)//2
+    c1 = _E(a[:l])
+    c2 = _E(a[l:])
+    s = ','.join(map(str, c1[0]+c1[1]+c2[0]+c2[1]))
+    print('={%s};' % s)
+
+def _E3(a):
+    'only for unittest'
+    l = len(a)//3
+    c1 = _E(a[:l])
+    c2 = _E(a[l:2*l])
+    c3 = _E(a[2*l:])
+    s = ','.join(map(str, c1[0]+c1[1]+c2[0]+c2[1]+c3[0]+c3[1]))
+    print('={%s};' % s)
+
+def _E6(a):
+    'only for unittest'
+    l = len(a)//6
+    c1 = _E(a[:l])
+    c2 = _E(a[l:2*l])
+    c3 = _E(a[2*l:3*l])
+    c4 = _E(a[3*l:4*l])
+    c5 = _E(a[4*l:5*l])
+    c6 = _E(a[5*l:])
+    s = ','.join(map(str, c1[0]+c1[1]+c2[0]+c2[1]+c3[0]+c3[1]+
+                          c4[0]+c4[1]+c5[0]+c5[1]+c6[0]+c6[1]))
+    print('={%s};' % s)
+
+def _hex(a):
+    'convert an GF(3^m) element to hex integer'
+    def f(a, b):
+        return str({0:0, 1:1, 2:2, 10:4, 11:5, 12:6, 20:8, 21:9, 22:'a'}[a*10+b])
+    l = [_get(a, i) for i in range(_m)] + [0] * (_m%2)
+    l.reverse()
+    x = [f(l[i],l[i+1]) for i in range(0,len(l),2)]
+    return ''.join(x)
+
+def _set_param(m, t):
+    'set the irreducible polynomial as $x^m + x^t + 2$'
+    global _m, _t, _ln, _p
     _m = m
+    _t = t
     _ln = (_m + (_W - 1) + 1) // _W # extra one bit for $_p$
     # assign $_p$
     _p1 = [0] * _ln
     _p2 = [0] * _ln
     _p2[0] = 1 # _p == x^m+x^t+2
-    p_t = it.table[m]
-    _p1[p_t // _W] |= 1 << (p_t % _W)
+    _p1[t // _W] |= 1 << (t % _W)
     _p1[m // _W] |= 1 << (m % _W)
     _p = [_p1, _p2]
 
-set_degree(97)
-
 def _clone(a):
     return [a[0][:], a[1][:]]
 
@@ -94,17 +132,17 @@ def _clr(a, pos):
     a[pos // _W] &= ~(1 << (pos % _W))
 
 def zero():
-    'returning the zero element in $GF(3^m)$, which is $[0]*m$'
+    'returning the zero element in $GF(3^m)$'
     return [[0] * _ln, [0] * _ln]
 
 def one():
-    'returning the element with value of one in $GF(3^m)$, which is $[1]+[0]*(m-1)$'
+    'returning the element with value of one in $GF(3^m)$'
     x = [0] * _ln
     x[0] = 1
     return [x, [0] * _ln]
 
 def two():
-    'returning the element with value of two in $GF(3^m)$, which is $[2]+[0]*(m-1)$'
+    'returning the element with value of two in $GF(3^m)$'
     x = [0] * _ln
     x[0] = 1
     return [[0] * _ln, x]
@@ -191,11 +229,10 @@ def reduct(ln, a):
     '''doing reduction
     The function returns the value of $a$ modulo $the irreducible trinomial$.
     $ln$ equals the degree of $a$.'''
-    assert ln >= _m
     p1 = [0] * len(a[0])
     p2 = [0] * len(a[0])
     _set(p1, ln)
-    _set(p1, ln - _m + it.table[_m])
+    _set(p1, ln - _m + _t)
     _set(p2, ln - _m)
     p = [p1, p2]
     x = ln
@@ -212,7 +249,6 @@ def reduct(ln, a):
 def _f1(number, a, c):
     '''doing multiplication of a constant $number$ and an element $a$ in GF(3^m)
     The function sets $c == number * a$ and returns nothing.'''
-    # assert a is not c
     if number == 0:
         l = len(a[0])
         c[0][:] = [0] * l
@@ -259,8 +295,8 @@ def cubic(a):
         if v == 1: _set(b1, 3 * i)
         elif v == 2: _set(b2, 3 * i)
     reduct(3 * _m - 3, b)
-    del b[0][_ln:]
-    del b[1][_ln:]
+    del b1[_ln:]
+    del b2[_ln:]
     return b
 
 _list1 = (0, 1, 2, 0, 1)
@@ -325,3 +361,27 @@ def inverse(a):
         neg(U, U)
     # assert r_m is not zero
     return U
+
+def _from_str(s):
+    ret = zero()
+    n = (_m + 7) // 8
+    x = 0
+    j = 0
+    for i in range(n):
+        c = int(s[j:j+2], 16)
+        x |= c << (4 * j)
+        j += 2
+    for i in range(_ln):
+        ret[0][i] = x & ((1 << _W) - 1)
+        x >>= _W
+    s = s[2*n:]
+    x = 0
+    j = 0
+    for i in range(n):
+        c = int(s[j:j+2], 16)
+        x |= c << (4 * j)
+        j += 2
+    for i in range(_ln):
+        ret[1][i] = x & ((1 << _W) - 1)
+        x >>= _W
+    return ret
