@@ -4,15 +4,21 @@ import unittest
 
 class Test(unittest.TestCase):
     def setUp(self):
-        ecc.f3m.set_degree(5)
-        
+        ecc.f3m._set_param(5, 4)
+
+    def test_order(self):
+        ecc.f3m._set_param(97, 12)
+        p = ecc.gen()
+        a = ecc.scalar_mult(ecc.order(), p)
+        self.assertTrue(a[0])
+                
     def test_add(self):
         # inf + inf == inf
         a = ecc.inf()
         b = ecc.inf()
         assert ecc.add(a, b)[0]
         # inf + p == p, p + inf == p
-        a = [False, f3m.zero(), f3m.one()]
+        a = [False, f3m.random(), f3m.random()]
         b = ecc.inf()
         assert ecc.add(a, b) == a
         assert ecc.add(b, a) == a
@@ -29,10 +35,6 @@ class Test(unittest.TestCase):
             c = [False, f3m._E([cx]), f3m._E([cy])]
             assert ecc.add(a, b) == c
             assert ecc.add(b, a) == c
-        # (0,1) + (0,2) == inf
-        a = [False, f3m.zero(), f3m.one()]
-        b = [False, f3m.zero(), f3m._E([2])]
-        assert ecc.add(a, b)[0]
         # P=E2(a^2 + a + 2 , a^4 + a^2 ) 
         # Q=E2(a^3 + a^2 + 1 , 2*a^4 + a + 1 )
         # P+Q == (2*a^4 + 2*a^3 + a^2 : 2*a^3 + a + 1)
@@ -57,7 +59,7 @@ class Test(unittest.TestCase):
         c = [False, f3m._E([2]), f3m.one()]
         assert ecc.scalar_mult(4, p) == c
         
-        f3m.set_degree(97)
+        f3m._set_param(97, 12)
         g = ecc.gen()
         v1 = ecc.scalar_mult(3, g)
         v2 = ecc.add(g, g)
