@@ -3,7 +3,7 @@ import unittest
 
 class Test(unittest.TestCase):
     def test_algo4a(self):
-        f3m.set_degree(97)
+        eta.init(151)
         t = f3m.random()
         u = f3m.random()
         c = eta._algo4a(t, u)
@@ -15,7 +15,7 @@ class Test(unittest.TestCase):
         self.assertEqual(b, c)
 
     def test_algo5(self):
-        f3m.set_degree(97)
+        eta.init(151)
         g = ecc.gen()
         w1 = eta._algo4(g[1], g[2], g[1], g[2])
         v1 = eta._algo5(g[1], g[2], g[1], g[2])
@@ -23,7 +23,7 @@ class Test(unittest.TestCase):
 
     def test_pairing(self):
         'test bilinear of the pairing'
-        f3m.set_degree(97)
+        eta.init(151)
         g = ecc.gen()
         v1 = eta.pairing(g[1], g[2], g[1], g[2])
         p = ecc.scalar_mult(3, g)
@@ -35,14 +35,14 @@ class Test(unittest.TestCase):
         'computation of $U ^ {3^{3m} - 1}$'
         # a = x*s+x+1
         # a^(3^15-1) == (x^4 + 2*x^3 + x^2 + x + 2)*s + x^3 + x + 2
-        eta.f3m.set_degree(5)
+        eta.f3m._set_param(5, 4)
         a = [[f3m._E([1, 1]), f3m._E([0, 1])], [f3m.zero(), f3m.zero()], [f3m.zero(), f3m.zero()]]
         v = eta._algo6(a)
         w = [[f3m._E([2, 1, 0, 1]), f3m._E([2, 1, 1, 2, 1])], [f3m.zero(), f3m.zero()], [f3m.zero(), f3m.zero()]]
         assert w == v
         
         m = 7
-        eta.f3m.set_degree(m)
+        eta.f3m._set_param(m, 2)
         a = f36m.random()
         n = 3 ** (3 * m) - 1
         v1 = eta._algo6(a)
@@ -52,7 +52,7 @@ class Test(unittest.TestCase):
     def test_algo7(self):
         'computation of $U ^ {3^m+1}$, $U \in T_2(F_{3^3M})$'
         m = 7
-        eta.f3m.set_degree(m)
+        eta.f3m._set_param(m, 2)
         a = f36m.random()
         n = 3 ** (3 * m) - 1 # putting a into T_2(F_33m)
         a = f36m.power(a, n)
@@ -64,7 +64,7 @@ class Test(unittest.TestCase):
     def test_algo8(self):
         'computing U^M, M=(3^{3m}-1)*(3^m+1)*(3^m+1-\mu*b*3^{(m+1)//2})'
         m = 5
-        eta.f3m.set_degree(m)
+        eta.f3m._set_param(m, 4)
         a = f36m.random()
         v1 = eta._algo8(a)
         n = 3 ** (3 * m) - 1
@@ -79,7 +79,7 @@ class Test(unittest.TestCase):
         self.assertEqual(v1, v2)
         
         m = 13
-        eta.f3m.set_degree(m)
+        eta.f3m._set_param(m, 4)
         a = f36m.random()
         v1 = eta._algo8(a)
         n = 3 ** (3 * m) - 1
@@ -92,3 +92,14 @@ class Test(unittest.TestCase):
         n = x * y
         v2 = f36m.power(a, n)
         self.assertEqual(v1, v2)
+
+    def test_init(self):
+        i = 0
+        for p in eta._params:
+            bit_num = int(p.split()[2])
+            eta.init(bit_num)
+            gen = ecc.gen()
+            order = ecc.order()
+            self.assertTrue(ecc.scalar_mult(order, gen)[0])
+            i += 1
+            if i == 10: break
