@@ -25,12 +25,25 @@ def in_f3m(a):
 class TestF3M(unittest.TestCase):
     def test_param(self):
         if f3m._W == 31:
-            f3m.set_degree(2) # erase
-            f3m.set_degree(97)
+            f3m._set_param(2, 1) # erase
+            f3m._set_param(97, 12)
             assert f3m._m == 97
             assert f3m._ln == 4
             assert f3m._p == [[4096, 0, 0, 16], [1, 0, 0, 0]]
     
+    def test_hex(self):
+        f3m._set_param(5, 4)
+        a = f3m._E([0])
+        assert f3m._hex(a) == '000'
+        a = f3m._E([1])
+        assert f3m._hex(a) == '001'
+        a = f3m._E([2])
+        assert f3m._hex(a) == '002'
+        a = f3m._E([0,2])
+        assert f3m._hex(a) == '008'
+        a = f3m._E([0,0,2])
+        assert f3m._hex(a) == '020'
+    
     def test_shift_down(self):
         if f3m._W == 31:
             a = [0x40000001, 1]
@@ -94,23 +107,23 @@ class TestF3M(unittest.TestCase):
             assert a == [[0x2AAAAAAA, 0x55555555], [0x55555555, 0x2AAAAAAA]]
     
     def test_random(self):
-        f3m.set_degree(97)
+        f3m._set_param(97, 12)
         f3m.random() # TODO: accurate test method
     
     def test_add(self):
-        f3m.set_degree(4)
+        f3m._set_param(4, 1)
         a = f3m._E([0,1,0,0])
         b = f3m._E([0,0,0,2])
         f3m.add(a, b, a)
         assert a == f3m._E([0, 1, 0, 2])
         
     def test_add1(self):
-        f3m.set_degree(4)
+        f3m._set_param(4, 1)
         a = f3m._E([1,1,0,0])
         f3m._add1(a)
         assert a == f3m._E([2, 1, 0, 0])
 
-        f3m.set_degree(97)
+        f3m._set_param(97, 12)
         a = f3m.random()
         b = f3m.one()
         c = f3m.zero()
@@ -119,12 +132,12 @@ class TestF3M(unittest.TestCase):
         assert a == c
 
     def test_add2(self):
-        f3m.set_degree(4)
+        f3m._set_param(4, 1)
         a = f3m._E([1,1,0,0])
         f3m._add2(a)
         assert a == f3m._E([0, 1, 0, 0])
 
-        f3m.set_degree(97)
+        f3m._set_param(97, 12)
         a = f3m.random()
         b = f3m.one()
         c = f3m.zero()
@@ -133,25 +146,25 @@ class TestF3M(unittest.TestCase):
         assert a == c
 
     def test_neg(self):
-        f3m.set_degree(4)
+        f3m._set_param(4, 1)
         a = f3m._E([0,1,0,2])
         f3m.neg(a, a)
         assert a == f3m._E([0, 2, 0, 1])
 
     def test_sub(self):
-        f3m.set_degree(4)
+        f3m._set_param(4, 1)
         a = f3m._E([2, 0, 0, 0])
         b = f3m._E([0, 1, 0, 0])
         f3m.sub(a, b, a)
         assert a == f3m._E([2, 2, 0, 0])
 
     def test_reduct(self):
-        f3m.set_degree(4)
+        f3m._set_param(4, 1)
         a = f3m._E([0, 0, 2, 1, 2])
         f3m.reduct(5, a)
         assert a == f3m._E([2, 1, 2, 1])
 
-        f3m.set_degree(97)
+        f3m._set_param(97, 12)
         a = f3m.random()
         b = f3m.zero()
         f3m.sub(a, f3m._p, b)
@@ -159,7 +172,7 @@ class TestF3M(unittest.TestCase):
         assert b == a
 
     def test_f1(self):
-        f3m.set_degree(4)
+        f3m._set_param(4, 1)
         a = f3m._E([0, 1, 0, 2])
         b = f3m.zero()
         f3m._f1(2, a, b)
@@ -170,7 +183,7 @@ class TestF3M(unittest.TestCase):
         assert b == f3m.zero()
     
     def test_f2(self):
-        f3m.set_degree(4)
+        f3m._set_param(4, 1)
         a = f3m._E([1, 0, 0, 1]) # 1 + x^3
         f3m._f2(a)
         assert a == f3m._E([1])
@@ -179,7 +192,7 @@ class TestF3M(unittest.TestCase):
         assert a == f3m._E([0,1])
 
     def test_mult(self):
-        f3m.set_degree(2)
+        f3m._set_param(2, 1)
         a = f3m._E([0, 1])
         b = f3m._E([0, 1])
         assert f3m.mult(a, b) == f3m._E([1, 2])
@@ -189,12 +202,12 @@ class TestF3M(unittest.TestCase):
         assert f3m.mult(a, b) == f3m._E([1, 0])
         
     def test_cubic(self):
-        f3m.set_degree(5)
+        f3m._set_param(5, 4)
         a = f3m._E([0, 1, 1, 2, 1])
         b = f3m.cubic(a)
         assert b == f3m._E([0, 1, 2, 0, 1])
         
-        f3m.set_degree(97)
+        f3m._set_param(97, 12)
         a = f3m.random()
         b = f3m.mult(a, a)
         b = f3m.mult(b, a)
@@ -202,11 +215,16 @@ class TestF3M(unittest.TestCase):
         self.assertEqual(b, c)
         
     def test_inverse(self):
-        f3m.set_degree(4)
+        f3m._set_param(4, 1)
         a_list = ([1, 1], [1, 1, 1], [1, 1, 1, 1], [1], [2],)
         a_inv_list = ([0, 1, 2, 1], [1, 0, 1, 2], [0, 0, 0, 1], [1], [2],)
         for a, a_inv in zip(a_list, a_inv_list):
             a1 = f3m.inverse(f3m._E(a))
             a2 = f3m._E(a_inv)
             assert a1 == a2
-    
\ No newline at end of file
+    
+        for _ in range(10):
+            a = f3m.random()
+            b = f3m.inverse(a)
+            c = f3m.mult(a, b)
+            assert c == f3m.one()
